package com.rwk.system.service;

import java.util.List;
import com.rwk.system.domain.RwkMeeting;

/**
 * 教育培训Service接口
 * 
 * @author ruoyi
 * @date 2024-12-05
 */
public interface IRwkMeetingService 
{
    /**
     * 查询教育培训
     * 
     * @param id 教育培训主键
     * @return 教育培训
     */
    public RwkMeeting selectRwkMeetingById(Long id);

    /**
     * 查询教育培训列表
     * 
     * @param rwkMeeting 教育培训
     * @return 教育培训集合
     */
    public List<RwkMeeting> selectRwkMeetingList(RwkMeeting rwkMeeting);

    /**
     * 新增教育培训
     * 
     * @param rwkMeeting 教育培训
     * @return 结果
     */
    public int insertRwkMeeting(RwkMeeting rwkMeeting);

    /**
     * 修改教育培训
     * 
     * @param rwkMeeting 教育培训
     * @return 结果
     */
    public int updateRwkMeeting(RwkMeeting rwkMeeting);

    /**
     * 批量删除教育培训
     * 
     * @param ids 需要删除的教育培训主键集合
     * @return 结果
     */
    public int deleteRwkMeetingByIds(String ids);

    /**
     * 删除教育培训信息
     * 
     * @param id 教育培训主键
     * @return 结果
     */
    public int deleteRwkMeetingById(Long id);
}
